@@ -7,14 +7,14 @@ mod tests {
     #[test]
     fn it_works() {
         for i in 0..20 {
-            println!("{} ist eine Primzahl: {}", i, check_prime(i));
+            println!("{} is a prime number: {}", i, check_prime(i));
         }
-        println!("Primzahlen von 1'000'000 bis 1'000'100: {:?}", check_area(1000000, 1000100));
+        println!("Prime numbers from 1'000'000 to 1'000'100: {:?}", check_area(1, 20));
         println!("It works!");
     }
 }
 
-fn check_prime(number:u32) -> bool {
+pub fn check_prime(number:u32) -> bool {
     if number < 1 { return false }
     for divisor in 2..number.integer_sqrt()+1 {
         if number%divisor == 0 { return false }
@@ -22,14 +22,14 @@ fn check_prime(number:u32) -> bool {
     true
 }
 
-fn check_area(start:u32, end:u32) -> Vec<u32> {
+pub fn check_area(start:u32, end:u32) -> Vec<u32> {
     let mut primes:Vec<u32> = Vec::new();
     let mut divisor:u32;
     if start < 1 && start >= end { return primes }
     for number in start..end {
         divisor = 2;
-        while number%divisor != 0 && divisor <= number.integer_sqrt()+1 { divisor = divisor + 1; }
-        if divisor >= number.integer_sqrt() { primes.push(number); }
+        while (number%divisor != 0) && (divisor <= number.integer_sqrt()) { divisor = divisor + 1; }
+        if (divisor >= number.integer_sqrt()+1) && (divisor != 1) { primes.push(number); }
     }
     primes
 }
\ No newline at end of file
